@@ -9,6 +9,7 @@ import qdarkstyle
 import requests
 import math
 import imgviz
+import sys
 
 from qtpy import QtCore
 from qtpy.QtCore import Qt
@@ -54,17 +55,34 @@ from enhancedlabelme.widgets import ZoomWidget
 LABEL_COLORMAP = imgviz.label_colormap(value=200)
 os.environ['QT_API'] = 'pyqt5'
 
+
 class PenStyleWindow(QtWidgets.QDialog):
     def __init__(self, parent=None):
         super(PenStyleWindow, self).__init__(parent)
         self.penColor = parent.canvas.penColor
         self.penThickness = parent.canvas.penThickness
         self.penStyle = parent.canvas.penStyle
+        
+        # Import .ui forms for the GUI using function resource_path()
+        self.penOptionForm = self.resource_path("enhancedlabelme/ui/penstylewindow.ui")
         self.initUI(parent)
 
+    # Define function to import external files when using PyInstaller.
+    def resource_path(self, relative_path):
+        """ Get absolute path to resource, works for dev and for PyInstaller """
+        try:
+            # PyInstaller creates a temp folder and stores path in _MEIPASS
+            base_path = sys._MEIPASS
+        except Exception:
+            base_path = osp.abspath(".")
+
+        return osp.join(base_path, relative_path)
+
+
     def initUI(self, parent):
-        option_ui = 'enhancedlabelme/ui/penstylewindow.ui'
-        uic.loadUi(option_ui, self)
+        # option_ui = 'enhancedlabelme/ui/penstylewindow.ui'
+        # uic.loadUi(option_ui, self)
+        uic.loadUi(self.penOptionForm, self)
         
         # Load current style
         self.horizontalSlider_thickness.setSliderPosition(self.penThickness * 10)
@@ -85,7 +103,7 @@ class PenStyleWindow(QtWidgets.QDialog):
             self.comboBox_color.setCurrentIndex(6)
         elif self.penColor == QtCore.Qt.cyan:
             self.comboBox_color.setCurrentIndex(7)
-        elif self.penColor == QtCore.Qt.magneta:
+        elif self.penColor == QtCore.Qt.magenta:
             self.comboBox_color.setCurrentIndex(8)        
         
         if self.penStyle == QtCore.Qt.SolidLine:
@@ -111,7 +129,7 @@ class PenStyleWindow(QtWidgets.QDialog):
     def drawLines(self, qp):
         pen = QtGui.QPen(self.penColor, self.penThickness, self.penStyle)
         qp.setPen(pen)
-        qp.drawLine(50, 160, 250, 160)
+        qp.drawLine(50, 170, 250, 170)
         
     def saveShape(self, value):
         if value == 'SolidLine':
@@ -140,7 +158,7 @@ class PenStyleWindow(QtWidgets.QDialog):
         elif value == 'Cyan':
             self.penColor = QtCore.Qt.cyan
         elif value == 'Pink':
-            self.penColor = QtCore.Qt.magneta
+            self.penColor = QtCore.Qt.magenta
         self.repaint()
         
     def saveThickness(self, value):
